from pathlib import Path
from typing import Union

class Drive:
    def __init__(self, root: Union[Path, str], create: bool = ...) -> None: ...
    def exists(self, key: str) -> bool: ...
    def save(self, key: str, data: bytes) -> bool: ...
    def load(self, key: str) -> bytes: ...
    def delete(self, key: str) -> bool: ...
