class MegaCloud:
    def __init__(self, email, password, root: str = ...) -> None: ...
    def exists(self, key: str) -> bool: ...
    def save(self, key: str, data: bytes) -> bool: ...
    def load(self, key: str) -> bytes: ...
    def delete(self, key: str) -> bool: ...
